==> haskell-juicypixels-3.2.8.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.8.1
id: JuicyPixels-3.2.8.1-BBigUmhgNXcICdQOH7vt3C
key: JuicyPixels-3.2.8.1-BBigUmhgNXcICdQOH7vt3C
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.Gif
    Codec.Picture.Png Codec.Picture.Jpg Codec.Picture.HDR
    Codec.Picture.Tga Codec.Picture.Tiff Codec.Picture.Metadata
    Codec.Picture.Metadata.Exif Codec.Picture.Saving
    Codec.Picture.Types Codec.Picture.ColorQuant
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
abi: 76b555dd7ef8ca62942899705501970a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/JuicyPixels-3.2.8.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/JuicyPixels-3.2.8.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/JuicyPixels-3.2.8.1
hs-libraries: HSJuicyPixels-3.2.8.1-BBigUmhgNXcICdQOH7vt3C
include-dirs: /usr/lib/ghc-8.0.1/site-local/JuicyPixels-3.2.8.1/include
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa transformers-0.5.2.0
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.2.8.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.8.1
id: JuicyPixels-3.2.8.1-8BpUIjM1ne1KhnHQeIHler
key: JuicyPixels-3.2.8.1-8BpUIjM1ne1KhnHQeIHler
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.Gif
    Codec.Picture.Png Codec.Picture.Jpg Codec.Picture.HDR
    Codec.Picture.Tga Codec.Picture.Tiff Codec.Picture.Metadata
    Codec.Picture.Metadata.Exif Codec.Picture.Saving
    Codec.Picture.Types Codec.Picture.ColorQuant
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
abi: 66dace618d290de82ebea87e6a93c715
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/JuicyPixels-3.2.8.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/JuicyPixels-3.2.8.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/JuicyPixels-3.2.8.1
hs-libraries: HSJuicyPixels-3.2.8.1-8BpUIjM1ne1KhnHQeIHler
include-dirs: /usr/lib/ghc-8.0.1/site-local/JuicyPixels-3.2.8.1/include
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ transformers-0.5.2.0
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
